import fastify from 'fastify'
import dotenv from 'dotenv'
import path from 'path'

// getting .env
dotenv.config({ path: path.join(path.resolve(), '/../../.env') })

// create server
const server = fastify()

/**
 *  add plugins
 *
 */
import { Liquid } from 'liquidjs'
import pov from 'point-of-view'

const engine = new Liquid({
    root: path.join(path.resolve(), '../frontend/views'),
    extname: '.liquid',
})

server.register(pov, {
    engine: {
        liquid: engine
    }
})

/**
 *  add routes
 *
 */
import actionHttp from './http/api/action.js'
import indexHttp from './http/index.js'
import staticHttp from './http/static.js'

server
    .register(actionHttp, {
        'prefix': '/api'
    })
    .register(indexHttp)
    .register(staticHttp)

export default server